Class: UspsApi::AdjustmentSubscription

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/adjustment_subscription.rb

Overview

The filters that should be applied to the subscription. The structure of this property will change dependent on the type of subscription a client is signing up for.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(crid: SKIP, event_types: SKIP, additional_properties: nil) ⇒ AdjustmentSubscription

Returns a new instance of AdjustmentSubscription.



57
58
59
60
61
62
63
64
# File 'lib/usps_api/models/adjustment_subscription.rb', line 57

def initialize(crid: SKIP, event_types: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @crid = crid unless crid == SKIP
  @event_types = event_types unless event_types == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cridString

Specify the Customer Registration ID that should be included in the subscription. Once a subscription is created this field cannot be changed through a future edit, instead the subscription should be deleted and a new subscription should be created.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/adjustment_subscription.rb', line 19

def crid
  @crid
end

#event_typesArray[EventType2]

Specify what adjustment events should be include in the subscription: </p> ALL - All Below Updates </p> CENSUS - Adjustments where package characteristics are captured during network processing that do

not align with the manifested characteristics

and lead to differences in manifested vs expected payments. DUPLICATES - Adjustments where multiple packages are shipped with the same barcode without corresponding

payment records for secondary packages.

UNMANIFESTED - Adjustments where packages are accepted and delivered without corresponding

payment records for the packages.

Returns:



34
35
36
# File 'lib/usps_api/models/adjustment_subscription.rb', line 34

def event_types
  @event_types
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/usps_api/models/adjustment_subscription.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  crid = hash.key?('CRID') ? hash['CRID'] : SKIP
  event_types = hash.key?('eventTypes') ? hash['eventTypes'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AdjustmentSubscription.new(crid: crid,
                             event_types: event_types,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
# File 'lib/usps_api/models/adjustment_subscription.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['crid'] = 'CRID'
  @_hash['event_types'] = 'eventTypes'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/usps_api/models/adjustment_subscription.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



45
46
47
48
49
50
# File 'lib/usps_api/models/adjustment_subscription.rb', line 45

def self.optionals
  %w[
    crid
    event_types
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/usps_api/models/adjustment_subscription.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} crid: #{@crid.inspect}, event_types: #{@event_types.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/usps_api/models/adjustment_subscription.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} crid: #{@crid}, event_types: #{@event_types}, additional_properties:"\
  " #{@additional_properties}>"
end