Class: UspsApi::Campaign1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/campaign1.rb

Overview

Campaign1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(campaign_id: SKIP, campaign_type: SKIP, mailpiece_shape: SKIP, mid: SKIP, submitter_name: SKIP, submitter_crid: SKIP, mail_owner_crid: SKIP, mail_owner_name: SKIP, campaign_code: SKIP, campaign_title: SKIP, brand_display_name: SKIP, start_date: SKIP, end_date: SKIP, start_serial: SKIP, end_serial: SKIP, campaign_source: SKIP, postal_one_saturation_job_id: SKIP, add_barcode: SKIP, barcode_count: SKIP, cancel: SKIP, created_datetime: SKIP, delete: SKIP, full_edit: SKIP, last_modified_datetime: SKIP, last_modified_source: SKIP, last_modified_username: SKIP, limited_edit: SKIP, no_edit: SKIP, status: SKIP, submitted_datetime: SKIP, is_shareable: SKIP, has_url_params: SKIP, additional_properties: nil) ⇒ Campaign1

Returns a new instance of Campaign1.



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/usps_api/models/campaign1.rb', line 280

def initialize(campaign_id: SKIP, campaign_type: SKIP,
               mailpiece_shape: SKIP, mid: SKIP, submitter_name: SKIP,
               submitter_crid: SKIP, mail_owner_crid: SKIP,
               mail_owner_name: SKIP, campaign_code: SKIP,
               campaign_title: SKIP, brand_display_name: SKIP,
               start_date: SKIP, end_date: SKIP, start_serial: SKIP,
               end_serial: SKIP, campaign_source: SKIP,
               postal_one_saturation_job_id: SKIP, add_barcode: SKIP,
               barcode_count: SKIP, cancel: SKIP, created_datetime: SKIP,
               delete: SKIP, full_edit: SKIP, last_modified_datetime: SKIP,
               last_modified_source: SKIP, last_modified_username: SKIP,
               limited_edit: SKIP, no_edit: SKIP, status: SKIP,
               submitted_datetime: SKIP, is_shareable: SKIP,
               has_url_params: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @campaign_id = campaign_id unless campaign_id == SKIP
  @campaign_type = campaign_type unless campaign_type == SKIP
  @mailpiece_shape = mailpiece_shape unless mailpiece_shape == SKIP
  @mid = mid unless mid == SKIP
  @submitter_name = submitter_name unless submitter_name == SKIP
  @submitter_crid = submitter_crid unless submitter_crid == SKIP
  @mail_owner_crid = mail_owner_crid unless mail_owner_crid == SKIP
  @mail_owner_name = mail_owner_name unless mail_owner_name == SKIP
  @campaign_code = campaign_code unless campaign_code == SKIP
  @campaign_title = campaign_title unless campaign_title == SKIP
  @brand_display_name = brand_display_name unless brand_display_name == SKIP
  @start_date = start_date unless start_date == SKIP
  @end_date = end_date unless end_date == SKIP
  @start_serial = start_serial unless start_serial == SKIP
  @end_serial = end_serial unless end_serial == SKIP
  @campaign_source = campaign_source unless campaign_source == SKIP
  unless postal_one_saturation_job_id == SKIP
    @postal_one_saturation_job_id =
      postal_one_saturation_job_id
  end
  @add_barcode = add_barcode unless add_barcode == SKIP
  @barcode_count = barcode_count unless barcode_count == SKIP
  @cancel = cancel unless cancel == SKIP
  @created_datetime = created_datetime unless created_datetime == SKIP
  @delete = delete unless delete == SKIP
  @full_edit = full_edit unless full_edit == SKIP
  @last_modified_datetime = last_modified_datetime unless last_modified_datetime == SKIP
  @last_modified_source = last_modified_source unless last_modified_source == SKIP
  @last_modified_username = last_modified_username unless last_modified_username == SKIP
  @limited_edit = limited_edit unless limited_edit == SKIP
  @no_edit = no_edit unless no_edit == SKIP
  @status = status unless status == SKIP
  @submitted_datetime =  unless  == SKIP
  @is_shareable = is_shareable unless is_shareable == SKIP
  @has_url_params = has_url_params unless has_url_params == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#add_barcodeTrueClass | FalseClass

Boolean that gives information on whether a campaign is eligible for having individual mailpieces added to it. This flag will be true only if the campaign has a NON-SEQ campaign type and an End Date in the future.

Returns:

  • (TrueClass | FalseClass)


110
111
112
# File 'lib/usps_api/models/campaign1.rb', line 110

def add_barcode
  @add_barcode
end

#barcode_countFloat

Number of mailpieces associated with the campaign. The number will only get greater than 0 for NON-SEQ campaigns.

Returns:

  • (Float)


115
116
117
# File 'lib/usps_api/models/campaign1.rb', line 115

def barcode_count
  @barcode_count
end

#brand_display_nameString

User defined field that is placed on Informed Delivery’s UIs when campaign is displayed.

Returns:

  • (String)


73
74
75
# File 'lib/usps_api/models/campaign1.rb', line 73

def brand_display_name
  @brand_display_name
end

#campaign_codeString

User defined field that describes the campaign being created. This field is put into the campaign reports created for the campaign.

Returns:

  • (String)


63
64
65
# File 'lib/usps_api/models/campaign1.rb', line 63

def campaign_code
  @campaign_code
end

#campaign_idString

Unique identifier for the campaign.

Returns:

  • (String)


15
16
17
# File 'lib/usps_api/models/campaign1.rb', line 15

def campaign_id
  @campaign_id
end

#campaign_sourceString

Gives information on system that was originally used to create campaign (e.g. API, PO!, MCP, Admin Console). This field will not update if campaign is subsequently edited or cancelled.

Returns:

  • (String)


99
100
101
# File 'lib/usps_api/models/campaign1.rb', line 99

def campaign_source
  @campaign_source
end

#campaign_titleString

User defined field that describes the campaign being created. This field is put into the campaign reports created for the campaign.

Returns:

  • (String)


68
69
70
# File 'lib/usps_api/models/campaign1.rb', line 68

def campaign_title
  @campaign_title
end

#campaign_typeString

Identifier on how the campaign should be applied to mail pieces

* A01 (Non-Sequential or NON-SEQ): Individual barcodes added to campaign

after submission

* A02 (Mailer ID or MID): All mailpieces with given Mailer ID added to

campaign

* A03 (Sequential or SEQ): All mailpieces with given Mailer ID and

serial range added to campaign

* A04 (Saturation or SAT): Mailpieces will be matched to saturation

pieces

Returns:

  • (String)


27
28
29
# File 'lib/usps_api/models/campaign1.rb', line 27

def campaign_type
  @campaign_type
end

#cancelTrueClass | FalseClass

Boolean that gives information on whether a campaign is eligible for cancellation. This flag will be true only if the campaign is in an Active status.

Returns:

  • (TrueClass | FalseClass)


121
122
123
# File 'lib/usps_api/models/campaign1.rb', line 121

def cancel
  @cancel
end

#created_datetimeDateTime

Timestamp of initial campaign creation. This timestamp will be returned in UTC.

Returns:

  • (DateTime)


126
127
128
# File 'lib/usps_api/models/campaign1.rb', line 126

def created_datetime
  @created_datetime
end

#deleteTrueClass | FalseClass

Boolean that gives information on whether a campaign is eligible for cancellation. This flag will be true only if the campaign is in a Submitted, Draft, or Inactive status.

Returns:

  • (TrueClass | FalseClass)


132
133
134
# File 'lib/usps_api/models/campaign1.rb', line 132

def delete
  @delete
end

#end_dateDate

Last day campaign will be displayed

Returns:

  • (Date)


81
82
83
# File 'lib/usps_api/models/campaign1.rb', line 81

def end_date
  @end_date
end

#end_serialString

The upper limit of the serial range for SEQ type campaigns. This field is required for SEQ campaigns only and is not allowed for submission for any other campaign types.

Returns:

  • (String)


93
94
95
# File 'lib/usps_api/models/campaign1.rb', line 93

def end_serial
  @end_serial
end

#full_editTrueClass | FalseClass

Boolean that gives information on whether a campaign is eligible for edit inclusive of the campaign’s MID. This flag will be true only if the campaign is in a Submitted and is not a NON-SEQ campaign with associated barcodes.

Returns:

  • (TrueClass | FalseClass)


139
140
141
# File 'lib/usps_api/models/campaign1.rb', line 139

def full_edit
  @full_edit
end

#has_url_paramsTrueClass | FalseClass

An indicator dictating whether a campaign is eligible for MID and Serial Number parameters to be appended to the end of the Target URL for tracking purposes. By default, the MID and Serial Number parameters for a given mailpiece will be added to end of the Target URL that users are taken to upon clicking on a campaign. If a mailer opts out of this feature, then these MID and Serial Number fields will not be appended to the campaign’s Target URL.

Returns:

  • (TrueClass | FalseClass)


197
198
199
# File 'lib/usps_api/models/campaign1.rb', line 197

def has_url_params
  @has_url_params
end

#is_shareableTrueClass | FalseClass

An indicator dictating whether a campaign is eligible for Social Sharing. By default, mail campaigns will be displayed alongside options to share the campaign to various social media platforms. If a mailer opts out of this feature, then these options will not be displayed with the campaign.

Returns:

  • (TrueClass | FalseClass)


187
188
189
# File 'lib/usps_api/models/campaign1.rb', line 187

def is_shareable
  @is_shareable
end

#last_modified_datetimeDateTime

Timestamp of last update made to campaign, inclusive of status changes that occur when a campaign activates or completes. This timestamp will be returned in UTC.

Returns:

  • (DateTime)


145
146
147
# File 'lib/usps_api/models/campaign1.rb', line 145

def last_modified_datetime
  @last_modified_datetime
end

#last_modified_sourceString

Gives information on system that was used to make last update to campaign (e.g. API, PO!, MCP, Admin Console). This field will update each time a campaign is created, edited, or cancelled.

Returns:

  • (String)


151
152
153
# File 'lib/usps_api/models/campaign1.rb', line 151

def last_modified_source
  @last_modified_source
end

#last_modified_usernameString

Gives information on Cust Reg user name associated with last update to campaign. This field will update each time a campaign is created, edited, or cancelled.

Returns:

  • (String)


157
158
159
# File 'lib/usps_api/models/campaign1.rb', line 157

def last_modified_username
  @last_modified_username
end

#limited_editTrueClass | FalseClass

Boolean that gives information on whether a campaign is eligible for edit, not inclusive of the campaign’s MID. This flag will be true only if the campaign is in a Submitted status, is a NON-SEQ campaign, and already has associated barcodes.

Returns:

  • (TrueClass | FalseClass)


164
165
166
# File 'lib/usps_api/models/campaign1.rb', line 164

def limited_edit
  @limited_edit
end

#mail_owner_cridString

Customer Registration ID (CRID) of the Mail Owner associated with the Informed Delivery campaign.

Returns:

  • (String)


54
55
56
# File 'lib/usps_api/models/campaign1.rb', line 54

def mail_owner_crid
  @mail_owner_crid
end

#mail_owner_nameString

Name of the Mail Owner associated with the Informed Delivery campaign.

Returns:

  • (String)


58
59
60
# File 'lib/usps_api/models/campaign1.rb', line 58

def mail_owner_name
  @mail_owner_name
end

#mailpiece_shapeString

Identifier on what types of mail pieces the campaign should be applied to

  • LT (Letter)

  • CD (Card)

  • FL (Flat)

Returns:

  • (String)


34
35
36
# File 'lib/usps_api/models/campaign1.rb', line 34

def mailpiece_shape
  @mailpiece_shape
end

#midString

The Mailer ID for the campaign - this field will be used to match IMBs to MID and SEQ type campaigns. If an IMB has the Mailer ID (MID) associated with an active MID/SEQ campaign, it is eligible to be displayed with the campaign’s image and Target URL.

Returns:

  • (String)


41
42
43
# File 'lib/usps_api/models/campaign1.rb', line 41

def mid
  @mid
end

#no_editTrueClass | FalseClass

Boolean that gives information on whether a campaign is not eligible for edit. This flag will be true if the campaign has an Active, Complete, Cancelled, or Deleted status.

Returns:

  • (TrueClass | FalseClass)


170
171
172
# File 'lib/usps_api/models/campaign1.rb', line 170

def no_edit
  @no_edit
end

#postal_one_saturation_job_idString

A PostalOne! generated unique identifier for a saturation type campaign. This field should not be used for NON-SEQ, MID, or SEQ campaigns.

Returns:

  • (String)


104
105
106
# File 'lib/usps_api/models/campaign1.rb', line 104

def postal_one_saturation_job_id
  @postal_one_saturation_job_id
end

#start_dateDate

First day campaign will be displayed

Returns:

  • (Date)


77
78
79
# File 'lib/usps_api/models/campaign1.rb', line 77

def start_date
  @start_date
end

#start_serialString

The lower limit of the serial range for SEQ type campaigns. This field is required for SEQ campaigns only and is not allowed for submission for any other campaign types.

Returns:

  • (String)


87
88
89
# File 'lib/usps_api/models/campaign1.rb', line 87

def start_serial
  @start_serial
end

#statusString

Status of campaign - possible values include Submitted, Active, Complete, Inactive, Draft, Cancelled, and Deleted

Returns:

  • (String)


175
176
177
# File 'lib/usps_api/models/campaign1.rb', line 175

def status
  @status
end

#submitted_datetimeDateTime

Timestamp of initial campaign submission. This timestamp will be returned in UTC.

Returns:

  • (DateTime)


180
181
182
# File 'lib/usps_api/models/campaign1.rb', line 180

def 
  @submitted_datetime
end

#submitter_cridString

The campaign submitter’s Customer Registration ID (CRID).

Returns:

  • (String)


49
50
51
# File 'lib/usps_api/models/campaign1.rb', line 49

def submitter_crid
  @submitter_crid
end

#submitter_nameString

The campaign submitter’s Name.

Returns:

  • (String)


45
46
47
# File 'lib/usps_api/models/campaign1.rb', line 45

def submitter_name
  @submitter_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/usps_api/models/campaign1.rb', line 336

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  campaign_id = hash.key?('campaignID') ? hash['campaignID'] : SKIP
  campaign_type = hash.key?('campaignType') ? hash['campaignType'] : SKIP
  mailpiece_shape =
    hash.key?('mailpieceShape') ? hash['mailpieceShape'] : SKIP
  mid = hash.key?('MID') ? hash['MID'] : SKIP
  submitter_name = hash.key?('submitterName') ? hash['submitterName'] : SKIP
  submitter_crid = hash.key?('submitterCRID') ? hash['submitterCRID'] : SKIP
  mail_owner_crid =
    hash.key?('mailOwnerCRID') ? hash['mailOwnerCRID'] : SKIP
  mail_owner_name =
    hash.key?('mailOwnerName') ? hash['mailOwnerName'] : SKIP
  campaign_code = hash.key?('campaignCode') ? hash['campaignCode'] : SKIP
  campaign_title = hash.key?('campaignTitle') ? hash['campaignTitle'] : SKIP
  brand_display_name =
    hash.key?('brandDisplayName') ? hash['brandDisplayName'] : SKIP
  start_date = hash.key?('startDate') ? hash['startDate'] : SKIP
  end_date = hash.key?('endDate') ? hash['endDate'] : SKIP
  start_serial = hash.key?('startSerial') ? hash['startSerial'] : SKIP
  end_serial = hash.key?('endSerial') ? hash['endSerial'] : SKIP
  campaign_source =
    hash.key?('campaignSource') ? hash['campaignSource'] : SKIP
  postal_one_saturation_job_id =
    hash.key?('postalOneSaturationJobID') ? hash['postalOneSaturationJobID'] : SKIP
  add_barcode = hash.key?('addBarcode') ? hash['addBarcode'] : SKIP
  barcode_count = hash.key?('barcodeCount') ? hash['barcodeCount'] : SKIP
  cancel = hash.key?('cancel') ? hash['cancel'] : SKIP
  created_datetime = if hash.key?('createdDatetime')
                       (DateTimeHelper.from_rfc3339(hash['createdDatetime']) if hash['createdDatetime'])
                     else
                       SKIP
                     end
  delete = hash.key?('delete') ? hash['delete'] : SKIP
  full_edit = hash.key?('fullEdit') ? hash['fullEdit'] : SKIP
  last_modified_datetime = if hash.key?('lastModifiedDatetime')
                             (DateTimeHelper.from_rfc3339(hash['lastModifiedDatetime']) if hash['lastModifiedDatetime'])
                           else
                             SKIP
                           end
  last_modified_source =
    hash.key?('lastModifiedSource') ? hash['lastModifiedSource'] : SKIP
  last_modified_username =
    hash.key?('lastModifiedUsername') ? hash['lastModifiedUsername'] : SKIP
  limited_edit = hash.key?('limitedEdit') ? hash['limitedEdit'] : SKIP
  no_edit = hash.key?('noEdit') ? hash['noEdit'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
   = if hash.key?('submittedDatetime')
                         (DateTimeHelper.from_rfc3339(hash['submittedDatetime']) if hash['submittedDatetime'])
                       else
                         SKIP
                       end
  is_shareable = hash.key?('isShareable') ? hash['isShareable'] : SKIP
  has_url_params = hash.key?('hasUrlParams') ? hash['hasUrlParams'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Campaign1.new(campaign_id: campaign_id,
                campaign_type: campaign_type,
                mailpiece_shape: mailpiece_shape,
                mid: mid,
                submitter_name: submitter_name,
                submitter_crid: submitter_crid,
                mail_owner_crid: mail_owner_crid,
                mail_owner_name: mail_owner_name,
                campaign_code: campaign_code,
                campaign_title: campaign_title,
                brand_display_name: brand_display_name,
                start_date: start_date,
                end_date: end_date,
                start_serial: start_serial,
                end_serial: end_serial,
                campaign_source: campaign_source,
                postal_one_saturation_job_id: postal_one_saturation_job_id,
                add_barcode: add_barcode,
                barcode_count: barcode_count,
                cancel: cancel,
                created_datetime: created_datetime,
                delete: delete,
                full_edit: full_edit,
                last_modified_datetime: last_modified_datetime,
                last_modified_source: last_modified_source,
                last_modified_username: last_modified_username,
                limited_edit: limited_edit,
                no_edit: no_edit,
                status: status,
                submitted_datetime: ,
                is_shareable: is_shareable,
                has_url_params: has_url_params,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/usps_api/models/campaign1.rb', line 200

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['campaign_id'] = 'campaignID'
  @_hash['campaign_type'] = 'campaignType'
  @_hash['mailpiece_shape'] = 'mailpieceShape'
  @_hash['mid'] = 'MID'
  @_hash['submitter_name'] = 'submitterName'
  @_hash['submitter_crid'] = 'submitterCRID'
  @_hash['mail_owner_crid'] = 'mailOwnerCRID'
  @_hash['mail_owner_name'] = 'mailOwnerName'
  @_hash['campaign_code'] = 'campaignCode'
  @_hash['campaign_title'] = 'campaignTitle'
  @_hash['brand_display_name'] = 'brandDisplayName'
  @_hash['start_date'] = 'startDate'
  @_hash['end_date'] = 'endDate'
  @_hash['start_serial'] = 'startSerial'
  @_hash['end_serial'] = 'endSerial'
  @_hash['campaign_source'] = 'campaignSource'
  @_hash['postal_one_saturation_job_id'] = 'postalOneSaturationJobID'
  @_hash['add_barcode'] = 'addBarcode'
  @_hash['barcode_count'] = 'barcodeCount'
  @_hash['cancel'] = 'cancel'
  @_hash['created_datetime'] = 'createdDatetime'
  @_hash['delete'] = 'delete'
  @_hash['full_edit'] = 'fullEdit'
  @_hash['last_modified_datetime'] = 'lastModifiedDatetime'
  @_hash['last_modified_source'] = 'lastModifiedSource'
  @_hash['last_modified_username'] = 'lastModifiedUsername'
  @_hash['limited_edit'] = 'limitedEdit'
  @_hash['no_edit'] = 'noEdit'
  @_hash['status'] = 'status'
  @_hash['submitted_datetime'] = 'submittedDatetime'
  @_hash['is_shareable'] = 'isShareable'
  @_hash['has_url_params'] = 'hasUrlParams'
  @_hash
end

.nullablesObject

An array for nullable fields



276
277
278
# File 'lib/usps_api/models/campaign1.rb', line 276

def self.nullables
  []
end

.optionalsObject

An array for optional fields



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/usps_api/models/campaign1.rb', line 238

def self.optionals
  %w[
    campaign_id
    campaign_type
    mailpiece_shape
    mid
    submitter_name
    submitter_crid
    mail_owner_crid
    mail_owner_name
    campaign_code
    campaign_title
    brand_display_name
    start_date
    end_date
    start_serial
    end_serial
    campaign_source
    postal_one_saturation_job_id
    add_barcode
    barcode_count
    cancel
    created_datetime
    delete
    full_edit
    last_modified_datetime
    last_modified_source
    last_modified_username
    limited_edit
    no_edit
    status
    submitted_datetime
    is_shareable
    has_url_params
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/usps_api/models/campaign1.rb', line 468

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} campaign_id: #{@campaign_id.inspect}, campaign_type:"\
  " #{@campaign_type.inspect}, mailpiece_shape: #{@mailpiece_shape.inspect}, mid:"\
  " #{@mid.inspect}, submitter_name: #{@submitter_name.inspect}, submitter_crid:"\
  " #{@submitter_crid.inspect}, mail_owner_crid: #{@mail_owner_crid.inspect}, mail_owner_name:"\
  " #{@mail_owner_name.inspect}, campaign_code: #{@campaign_code.inspect}, campaign_title:"\
  " #{@campaign_title.inspect}, brand_display_name: #{@brand_display_name.inspect},"\
  " start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect}, start_serial:"\
  " #{@start_serial.inspect}, end_serial: #{@end_serial.inspect}, campaign_source:"\
  " #{@campaign_source.inspect}, postal_one_saturation_job_id:"\
  " #{@postal_one_saturation_job_id.inspect}, add_barcode: #{@add_barcode.inspect},"\
  " barcode_count: #{@barcode_count.inspect}, cancel: #{@cancel.inspect}, created_datetime:"\
  " #{@created_datetime.inspect}, delete: #{@delete.inspect}, full_edit:"\
  " #{@full_edit.inspect}, last_modified_datetime: #{@last_modified_datetime.inspect},"\
  " last_modified_source: #{@last_modified_source.inspect}, last_modified_username:"\
  " #{@last_modified_username.inspect}, limited_edit: #{@limited_edit.inspect}, no_edit:"\
  " #{@no_edit.inspect}, status: #{@status.inspect}, submitted_datetime:"\
  " #{@submitted_datetime.inspect}, is_shareable: #{@is_shareable.inspect}, has_url_params:"\
  " #{@has_url_params.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_created_datetimeObject



436
437
438
# File 'lib/usps_api/models/campaign1.rb', line 436

def to_custom_created_datetime
  DateTimeHelper.to_rfc3339(created_datetime)
end

#to_custom_last_modified_datetimeObject



440
441
442
# File 'lib/usps_api/models/campaign1.rb', line 440

def to_custom_last_modified_datetime
  DateTimeHelper.to_rfc3339(last_modified_datetime)
end

#to_custom_submitted_datetimeObject



444
445
446
# File 'lib/usps_api/models/campaign1.rb', line 444

def 
  DateTimeHelper.to_rfc3339()
end

#to_sObject

Provides a human-readable string representation of the object.



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/usps_api/models/campaign1.rb', line 449

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} campaign_id: #{@campaign_id}, campaign_type: #{@campaign_type},"\
  " mailpiece_shape: #{@mailpiece_shape}, mid: #{@mid}, submitter_name: #{@submitter_name},"\
  " submitter_crid: #{@submitter_crid}, mail_owner_crid: #{@mail_owner_crid}, mail_owner_name:"\
  " #{@mail_owner_name}, campaign_code: #{@campaign_code}, campaign_title: #{@campaign_title},"\
  " brand_display_name: #{@brand_display_name}, start_date: #{@start_date}, end_date:"\
  " #{@end_date}, start_serial: #{@start_serial}, end_serial: #{@end_serial}, campaign_source:"\
  " #{@campaign_source}, postal_one_saturation_job_id: #{@postal_one_saturation_job_id},"\
  " add_barcode: #{@add_barcode}, barcode_count: #{@barcode_count}, cancel: #{@cancel},"\
  " created_datetime: #{@created_datetime}, delete: #{@delete}, full_edit: #{@full_edit},"\
  " last_modified_datetime: #{@last_modified_datetime}, last_modified_source:"\
  " #{@last_modified_source}, last_modified_username: #{@last_modified_username},"\
  " limited_edit: #{@limited_edit}, no_edit: #{@no_edit}, status: #{@status},"\
  " submitted_datetime: #{@submitted_datetime}, is_shareable: #{@is_shareable},"\
  " has_url_params: #{@has_url_params}, additional_properties: #{@additional_properties}>"
end