Class: UspsApi::Carrier
- Defined in:
- lib/usps_api/models/carrier.rb
Overview
Details about the carrier for the appointment.
Instance Attribute Summary collapse
-
#carrier_crid ⇒ String
CRID of the carrier.
-
#carrier_name ⇒ String
Name of the carrier.
-
#common_contact ⇒ Array[CommonContact]
Contact details of the appointment requestor.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(carrier_name: SKIP, carrier_crid: SKIP, common_contact: SKIP, additional_properties: nil) ⇒ Carrier
constructor
A new instance of Carrier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(carrier_name: SKIP, carrier_crid: SKIP, common_contact: SKIP, additional_properties: nil) ⇒ Carrier
Returns a new instance of Carrier.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/carrier.rb', line 47 def initialize(carrier_name: SKIP, carrier_crid: SKIP, common_contact: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @carrier_name = carrier_name unless carrier_name == SKIP @carrier_crid = carrier_crid unless carrier_crid == SKIP @common_contact = common_contact unless common_contact == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#carrier_crid ⇒ String
CRID of the carrier
18 19 20 |
# File 'lib/usps_api/models/carrier.rb', line 18 def carrier_crid @carrier_crid end |
#carrier_name ⇒ String
Name of the carrier. Required for Create actions.
14 15 16 |
# File 'lib/usps_api/models/carrier.rb', line 14 def carrier_name @carrier_name end |
#common_contact ⇒ Array[CommonContact]
Contact details of the appointment requestor.
22 23 24 |
# File 'lib/usps_api/models/carrier.rb', line 22 def common_contact @common_contact end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/usps_api/models/carrier.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP carrier_crid = hash.key?('carrierCRID') ? hash['carrierCRID'] : SKIP # Parameter is an array, so we need to iterate through it common_contact = nil unless hash['commonContact'].nil? common_contact = [] hash['commonContact'].each do |structure| common_contact << (CommonContact.from_hash(structure) if structure) end end common_contact = SKIP unless hash.key?('commonContact') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Carrier.new(carrier_name: carrier_name, carrier_crid: carrier_crid, common_contact: common_contact, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/carrier.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['carrier_name'] = 'carrierName' @_hash['carrier_crid'] = 'carrierCRID' @_hash['common_contact'] = 'commonContact' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/carrier.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/carrier.rb', line 34 def self.optionals %w[ carrier_name carrier_crid common_contact ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/usps_api/models/carrier.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} carrier_name: #{@carrier_name.inspect}, carrier_crid:"\ " #{@carrier_crid.inspect}, common_contact: #{@common_contact.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/usps_api/models/carrier.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} carrier_name: #{@carrier_name}, carrier_crid: #{@carrier_crid},"\ " common_contact: #{@common_contact}, additional_properties: #{@additional_properties}>" end |