Class: UspsApi::ConsigneeFacility

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/consignee_facility.rb

Overview

Consignee Facility details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(facility_number: SKIP, facility_type: SKIP, additional_properties: nil) ⇒ ConsigneeFacility

Returns a new instance of ConsigneeFacility.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/consignee_facility.rb', line 41

def initialize(facility_number: SKIP, facility_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @facility_number = facility_number unless facility_number == SKIP
  @facility_type = facility_type unless facility_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#facility_numberString

Facility number. Required for Create actions.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/consignee_facility.rb', line 14

def facility_number
  @facility_number
end

#facility_typeString

Type of facility

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/consignee_facility.rb', line 18

def facility_type
  @facility_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/usps_api/models/consignee_facility.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  facility_number =
    hash.key?('facilityNumber') ? hash['facilityNumber'] : SKIP
  facility_type = hash.key?('facilityType') ? hash['facilityType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsigneeFacility.new(facility_number: facility_number,
                        facility_type: facility_type,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/consignee_facility.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['facility_number'] = 'facilityNumber'
  @_hash['facility_type'] = 'facilityType'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/consignee_facility.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/consignee_facility.rb', line 29

def self.optionals
  %w[
    facility_number
    facility_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/usps_api/models/consignee_facility.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} facility_number: #{@facility_number.inspect}, facility_type:"\
  " #{@facility_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/usps_api/models/consignee_facility.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} facility_number: #{@facility_number}, facility_type: #{@facility_type},"\
  " additional_properties: #{@additional_properties}>"
end