Class: UspsApi::ContaineridPackagesBody

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/containerid_packages_body.rb

Overview

ContaineridPackagesBody Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(allow_manifested_labels: SKIP, tracking_numbers: SKIP, additional_properties: nil) ⇒ ContaineridPackagesBody

Returns a new instance of ContaineridPackagesBody.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/containerid_packages_body.rb', line 41

def initialize(allow_manifested_labels: SKIP, tracking_numbers: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @allow_manifested_labels = allow_manifested_labels unless allow_manifested_labels == SKIP
  @tracking_numbers = tracking_numbers unless tracking_numbers == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#allow_manifested_labelsTrueClass | FalseClass

Allow labels that have manifested to be added to the container.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/usps_api/models/containerid_packages_body.rb', line 14

def allow_manifested_labels
  @allow_manifested_labels
end

#tracking_numbersArray[String]

List of tracking numbers for the packages that are in the container.

Returns:

  • (Array[String])


18
19
20
# File 'lib/usps_api/models/containerid_packages_body.rb', line 18

def tracking_numbers
  @tracking_numbers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/usps_api/models/containerid_packages_body.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  allow_manifested_labels =
    hash.key?('allowManifestedLabels') ? hash['allowManifestedLabels'] : SKIP
  tracking_numbers =
    hash.key?('trackingNumbers') ? hash['trackingNumbers'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ContaineridPackagesBody.new(allow_manifested_labels: allow_manifested_labels,
                              tracking_numbers: tracking_numbers,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/containerid_packages_body.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['allow_manifested_labels'] = 'allowManifestedLabels'
  @_hash['tracking_numbers'] = 'trackingNumbers'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/containerid_packages_body.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/containerid_packages_body.rb', line 29

def self.optionals
  %w[
    allow_manifested_labels
    tracking_numbers
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
87
# File 'lib/usps_api/models/containerid_packages_body.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_manifested_labels: #{@allow_manifested_labels.inspect},"\
  " tracking_numbers: #{@tracking_numbers.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/usps_api/models/containerid_packages_body.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_manifested_labels: #{@allow_manifested_labels}, tracking_numbers:"\
  " #{@tracking_numbers}, additional_properties: #{@additional_properties}>"
end