Class: UspsApi::DomesticOptionsResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UspsApi::DomesticOptionsResponse
- Defined in:
- lib/usps_api/models/domestic_options_response.rb
Overview
TBD
Instance Attribute Summary collapse
-
#destination_zip_code ⇒ String
This is the destination ZIP Code™ for the package.
-
#origin_zip_code ⇒ String
This is the originating ZIP Code™ for the package.
-
#pricing_options ⇒ Array[DomesticPricingOption]
List of domestic pricing options.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(origin_zip_code: SKIP, destination_zip_code: SKIP, pricing_options: SKIP, additional_properties: nil) ⇒ DomesticOptionsResponse
constructor
A new instance of DomesticOptionsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(origin_zip_code: SKIP, destination_zip_code: SKIP, pricing_options: SKIP, additional_properties: nil) ⇒ DomesticOptionsResponse
Returns a new instance of DomesticOptionsResponse.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 47 def initialize(origin_zip_code: SKIP, destination_zip_code: SKIP, pricing_options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @origin_zip_code = origin_zip_code unless origin_zip_code == SKIP @destination_zip_code = destination_zip_code unless destination_zip_code == SKIP @pricing_options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#destination_zip_code ⇒ String
This is the destination ZIP Code™ for the package.
18 19 20 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 18 def destination_zip_code @destination_zip_code end |
#origin_zip_code ⇒ String
This is the originating ZIP Code™ for the package.
14 15 16 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 14 def origin_zip_code @origin_zip_code end |
#pricing_options ⇒ Array[DomesticPricingOption]
List of domestic pricing options
22 23 24 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 22 def @pricing_options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. origin_zip_code = hash.key?('originZIPCode') ? hash['originZIPCode'] : SKIP destination_zip_code = hash.key?('destinationZIPCode') ? hash['destinationZIPCode'] : SKIP # Parameter is an array, so we need to iterate through it = nil unless hash['pricingOptions'].nil? = [] hash['pricingOptions'].each do |structure| << (DomesticPricingOption.from_hash(structure) if structure) end end = SKIP unless hash.key?('pricingOptions') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DomesticOptionsResponse.new(origin_zip_code: origin_zip_code, destination_zip_code: destination_zip_code, pricing_options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['origin_zip_code'] = 'originZIPCode' @_hash['destination_zip_code'] = 'destinationZIPCode' @_hash['pricing_options'] = 'pricingOptions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 34 def self.optionals %w[ origin_zip_code destination_zip_code pricing_options ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
94 95 96 97 98 99 100 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 94 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} origin_zip_code: #{@origin_zip_code.inspect}, destination_zip_code:"\ " #{@destination_zip_code.inspect}, pricing_options: #{@pricing_options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/usps_api/models/domestic_options_response.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} origin_zip_code: #{@origin_zip_code}, destination_zip_code:"\ " #{@destination_zip_code}, pricing_options: #{@pricing_options}, additional_properties:"\ " #{@additional_properties}>" end |