Class: UspsApi::ExtraService

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/extra_service.rb

Overview

ExtraService Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(extra_service_name: SKIP, extra_service_sku: SKIP, extra_service_amount: SKIP, extra_service_code: SKIP, additional_properties: nil) ⇒ ExtraService

Returns a new instance of ExtraService.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/usps_api/models/extra_service.rb', line 53

def initialize(extra_service_name: SKIP, extra_service_sku: SKIP,
               extra_service_amount: SKIP, extra_service_code: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @extra_service_name = extra_service_name unless extra_service_name == SKIP
  @extra_service_sku = extra_service_sku unless extra_service_sku == SKIP
  @extra_service_amount = extra_service_amount unless extra_service_amount == SKIP
  @extra_service_code = extra_service_code unless extra_service_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#extra_service_amountFloat

Amount charged for the extra service

Returns:

  • (Float)


22
23
24
# File 'lib/usps_api/models/extra_service.rb', line 22

def extra_service_amount
  @extra_service_amount
end

#extra_service_codeString

Number associated with the extra service

Returns:

  • (String)


26
27
28
# File 'lib/usps_api/models/extra_service.rb', line 26

def extra_service_code
  @extra_service_code
end

#extra_service_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/extra_service.rb', line 14

def extra_service_name
  @extra_service_name
end

#extra_service_skuString

SKU code for the extra service

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/extra_service.rb', line 18

def extra_service_sku
  @extra_service_sku
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/usps_api/models/extra_service.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  extra_service_name =
    hash.key?('extraServiceName') ? hash['extraServiceName'] : SKIP
  extra_service_sku =
    hash.key?('extraServiceSku') ? hash['extraServiceSku'] : SKIP
  extra_service_amount =
    hash.key?('extraServiceAmount') ? hash['extraServiceAmount'] : SKIP
  extra_service_code =
    hash.key?('extraServiceCode') ? hash['extraServiceCode'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ExtraService.new(extra_service_name: extra_service_name,
                   extra_service_sku: extra_service_sku,
                   extra_service_amount: extra_service_amount,
                   extra_service_code: extra_service_code,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/usps_api/models/extra_service.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['extra_service_name'] = 'extraServiceName'
  @_hash['extra_service_sku'] = 'extraServiceSku'
  @_hash['extra_service_amount'] = 'extraServiceAmount'
  @_hash['extra_service_code'] = 'extraServiceCode'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/usps_api/models/extra_service.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/usps_api/models/extra_service.rb', line 39

def self.optionals
  %w[
    extra_service_name
    extra_service_sku
    extra_service_amount
    extra_service_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
110
# File 'lib/usps_api/models/extra_service.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} extra_service_name: #{@extra_service_name.inspect}, extra_service_sku:"\
  " #{@extra_service_sku.inspect}, extra_service_amount: #{@extra_service_amount.inspect},"\
  " extra_service_code: #{@extra_service_code.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
101
# File 'lib/usps_api/models/extra_service.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} extra_service_name: #{@extra_service_name}, extra_service_sku:"\
  " #{@extra_service_sku}, extra_service_amount: #{@extra_service_amount}, extra_service_code:"\
  " #{@extra_service_code}, additional_properties: #{@additional_properties}>"
end