Class: UspsApi::Fee1
- Defined in:
- lib/usps_api/models/fee1.rb
Overview
Fee1 Model.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the fee.
-
#price ⇒ Float
The price for the fee.
-
#sku ⇒ String
The pricing SKU for the fee.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, sku: SKIP, price: SKIP, additional_properties: nil) ⇒ Fee1
constructor
A new instance of Fee1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, sku: SKIP, price: SKIP, additional_properties: nil) ⇒ Fee1
Returns a new instance of Fee1.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/usps_api/models/fee1.rb', line 47 def initialize(name: SKIP, sku: SKIP, price: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @sku = sku unless sku == SKIP @price = price unless price == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
The name of the fee.
14 15 16 |
# File 'lib/usps_api/models/fee1.rb', line 14 def name @name end |
#price ⇒ Float
The price for the fee.
22 23 24 |
# File 'lib/usps_api/models/fee1.rb', line 22 def price @price end |
#sku ⇒ String
The pricing SKU for the fee.
18 19 20 |
# File 'lib/usps_api/models/fee1.rb', line 18 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/usps_api/models/fee1.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP sku = hash.key?('SKU') ? hash['SKU'] : SKIP price = hash.key?('price') ? hash['price'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Fee1.new(name: name, sku: sku, price: price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/fee1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['sku'] = 'SKU' @_hash['price'] = 'price' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/fee1.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/fee1.rb', line 34 def self.optionals %w[ name sku price ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/usps_api/models/fee1.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, sku: #{@sku.inspect}, price: #{@price.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/usps_api/models/fee1.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, sku: #{@sku}, price: #{@price}, additional_properties:"\ " #{@additional_properties}>" end |