Class: UspsApi::Fee2
- Defined in:
- lib/usps_api/models/fee2.rb
Overview
Fees associated with the container
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the fee.
-
#price ⇒ Float
The price for the fee.
-
#sku ⇒ String
Pricing SKU of the fee.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name: SKIP, sku: SKIP, price: SKIP) ⇒ Fee2
constructor
A new instance of Fee2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, sku: SKIP, price: SKIP) ⇒ Fee2
Returns a new instance of Fee2.
47 48 49 50 51 |
# File 'lib/usps_api/models/fee2.rb', line 47 def initialize(name: SKIP, sku: SKIP, price: SKIP) @name = name unless name == SKIP @sku = sku unless sku == SKIP @price = price unless price == SKIP end |
Instance Attribute Details
#name ⇒ String
Name of the fee.
14 15 16 |
# File 'lib/usps_api/models/fee2.rb', line 14 def name @name end |
#price ⇒ Float
The price for the fee.
22 23 24 |
# File 'lib/usps_api/models/fee2.rb', line 22 def price @price end |
#sku ⇒ String
Pricing SKU of the fee.
18 19 20 |
# File 'lib/usps_api/models/fee2.rb', line 18 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/usps_api/models/fee2.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP sku = hash.key?('SKU') ? hash['SKU'] : SKIP price = hash.key?('price') ? hash['price'] : SKIP # Create object from extracted values. Fee2.new(name: name, sku: sku, price: price) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/usps_api/models/fee2.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['sku'] = 'SKU' @_hash['price'] = 'price' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/usps_api/models/fee2.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/usps_api/models/fee2.rb', line 34 def self.optionals %w[ name sku price ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 |
# File 'lib/usps_api/models/fee2.rb', line 70 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 |
# File 'lib/usps_api/models/fee2.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, sku: #{@sku.inspect}, price: #{@price.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/usps_api/models/fee2.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, sku: #{@sku}, price: #{@price}>" end |