Class: UspsApi::FileStatus

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/file_status.rb

Overview

FileStatus Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(file_type: SKIP, mailing_date_indicated_in_file: SKIP, submission_date: SKIP, additional_properties: nil) ⇒ FileStatus

Returns a new instance of FileStatus.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/usps_api/models/file_status.rb', line 47

def initialize(file_type: SKIP, mailing_date_indicated_in_file: SKIP,
               submission_date: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @file_type = file_type unless file_type == SKIP
  unless mailing_date_indicated_in_file == SKIP
    @mailing_date_indicated_in_file =
      mailing_date_indicated_in_file
  end
  @submission_date = submission_date unless submission_date == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#file_typeFileType

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/usps_api/models/file_status.rb', line 14

def file_type
  @file_type
end

#mailing_date_indicated_in_fileDate

TODO: Write general description for this method

Returns:

  • (Date)


18
19
20
# File 'lib/usps_api/models/file_status.rb', line 18

def mailing_date_indicated_in_file
  @mailing_date_indicated_in_file
end

#submission_dateDate

TODO: Write general description for this method

Returns:

  • (Date)


22
23
24
# File 'lib/usps_api/models/file_status.rb', line 22

def submission_date
  @submission_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/usps_api/models/file_status.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  file_type = hash.key?('fileType') ? hash['fileType'] : SKIP
  mailing_date_indicated_in_file =
    hash.key?('mailingDateIndicatedInFile') ? hash['mailingDateIndicatedInFile'] : SKIP
  submission_date =
    hash.key?('submissionDate') ? hash['submissionDate'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  FileStatus.new(file_type: file_type,
                 mailing_date_indicated_in_file: mailing_date_indicated_in_file,
                 submission_date: submission_date,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/file_status.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['file_type'] = 'fileType'
  @_hash['mailing_date_indicated_in_file'] = 'mailingDateIndicatedInFile'
  @_hash['submission_date'] = 'submissionDate'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/file_status.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/file_status.rb', line 34

def self.optionals
  %w[
    file_type
    mailing_date_indicated_in_file
    submission_date
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/usps_api/models/file_status.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} file_type: #{@file_type.inspect}, mailing_date_indicated_in_file:"\
  " #{@mailing_date_indicated_in_file.inspect}, submission_date: #{@submission_date.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/usps_api/models/file_status.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} file_type: #{@file_type}, mailing_date_indicated_in_file:"\
  " #{@mailing_date_indicated_in_file}, submission_date: #{@submission_date},"\
  " additional_properties: #{@additional_properties}>"
end