Class: UspsApi::Imb2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/imb2.rb

Overview

Imb2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(imb: SKIP, piece_id: SKIP, errors: SKIP, additional_properties: nil) ⇒ Imb2

Returns a new instance of Imb2.



51
52
53
54
55
56
57
58
59
60
# File 'lib/usps_api/models/imb2.rb', line 51

def initialize(imb: SKIP, piece_id: SKIP, errors: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @imb = imb unless imb == SKIP
  @piece_id = piece_id unless piece_id == SKIP
  @errors = errors unless errors == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#errorsArray[Error3]

The unique pieceID of the IMB for the campaign. This pieceID will be unique if an IMB is added to multiple campaigns.

Returns:



24
25
26
# File 'lib/usps_api/models/imb2.rb', line 24

def errors
  @errors
end

#imbString

The IMB included in the request.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/imb2.rb', line 14

def imb
  @imb
end

#piece_idInteger

The unique pieceID of the IMB for the campaign. This pieceID will be unique if an IMB is added to multiple campaigns.

Returns:

  • (Integer)


19
20
21
# File 'lib/usps_api/models/imb2.rb', line 19

def piece_id
  @piece_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/usps_api/models/imb2.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  imb = hash.key?('IMB') ? hash['IMB'] : SKIP
  piece_id = hash.key?('pieceID') ? hash['pieceID'] : SKIP
  # Parameter is an array, so we need to iterate through it
  errors = nil
  unless hash['errors'].nil?
    errors = []
    hash['errors'].each do |structure|
      errors << (Error3.from_hash(structure) if structure)
    end
  end

  errors = SKIP unless hash.key?('errors')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Imb2.new(imb: imb,
           piece_id: piece_id,
           errors: errors,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/usps_api/models/imb2.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['imb'] = 'IMB'
  @_hash['piece_id'] = 'pieceID'
  @_hash['errors'] = 'errors'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
48
49
# File 'lib/usps_api/models/imb2.rb', line 45

def self.nullables
  %w[
    piece_id
  ]
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/usps_api/models/imb2.rb', line 36

def self.optionals
  %w[
    imb
    piece_id
    errors
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/usps_api/models/imb2.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} imb: #{@imb.inspect}, piece_id: #{@piece_id.inspect}, errors:"\
  " #{@errors.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/usps_api/models/imb2.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} imb: #{@imb}, piece_id: #{@piece_id}, errors: #{@errors},"\
  " additional_properties: #{@additional_properties}>"
end