Class: UspsApi::PickupAddressee

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/pickup_addressee.rb

Overview

Fields used to identity the entity receiving a mail piece or package

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name:, last_name:, firm: SKIP, additional_properties: nil) ⇒ PickupAddressee

Returns a new instance of PickupAddressee.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/pickup_addressee.rb', line 47

def initialize(first_name:, last_name:, firm: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name
  @last_name = last_name
  @firm = firm unless firm == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#firmString

This is the firm corresponding to the address. Firm is required for all domestic addresses in international label requests due to customs form requirements.

Returns:

  • (String)


24
25
26
# File 'lib/usps_api/models/pickup_addressee.rb', line 24

def firm
  @firm
end

#first_nameString

This is the first name corresponding to the address.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/pickup_addressee.rb', line 14

def first_name
  @first_name
end

#last_nameString

This is the last name corresponding to the address.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/pickup_addressee.rb', line 18

def last_name
  @last_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/pickup_addressee.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('firstName') ? hash['firstName'] : nil
  last_name = hash.key?('lastName') ? hash['lastName'] : nil
  firm = hash.key?('firm') ? hash['firm'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PickupAddressee.new(first_name: first_name,
                      last_name: last_name,
                      firm: firm,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/usps_api/models/pickup_addressee.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash['firm'] = 'firm'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/pickup_addressee.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
# File 'lib/usps_api/models/pickup_addressee.rb', line 36

def self.optionals
  %w[
    firm
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/usps_api/models/pickup_addressee.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect}, firm:"\
  " #{@firm.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/usps_api/models/pickup_addressee.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, firm: #{@firm},"\
  " additional_properties: #{@additional_properties}>"
end