Class: UspsApi::PreSortLevel2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/pre_sort_level2.rb

Overview

Object for the preSortLevel elements

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(container_level: SKIP, count: SKIP, additional_properties: nil) ⇒ PreSortLevel2

Returns a new instance of PreSortLevel2.



41
42
43
44
45
46
47
48
49
# File 'lib/usps_api/models/pre_sort_level2.rb', line 41

def initialize(container_level: SKIP, count: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @container_level = container_level unless container_level == SKIP
  @count = count unless count == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#container_levelContainerLevel

Presort content level information. Required for Create actions.

Returns:



14
15
16
# File 'lib/usps_api/models/pre_sort_level2.rb', line 14

def container_level
  @container_level
end

#countInteger

Count for preSortLevel

Returns:

  • (Integer)


18
19
20
# File 'lib/usps_api/models/pre_sort_level2.rb', line 18

def count
  @count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/usps_api/models/pre_sort_level2.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  container_level =
    hash.key?('containerLevel') ? hash['containerLevel'] : SKIP
  count = hash.key?('count') ? hash['count'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PreSortLevel2.new(container_level: container_level,
                    count: count,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/pre_sort_level2.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['container_level'] = 'containerLevel'
  @_hash['count'] = 'count'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/pre_sort_level2.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/pre_sort_level2.rb', line 29

def self.optionals
  %w[
    container_level
    count
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/usps_api/models/pre_sort_level2.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} container_level: #{@container_level.inspect}, count: #{@count.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/usps_api/models/pre_sort_level2.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} container_level: #{@container_level}, count: #{@count},"\
  " additional_properties: #{@additional_properties}>"
end