Class: UspsApi::Previous

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/previous.rb

Overview

Link to the previous page of results.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(href: SKIP, method: SKIP, body: SKIP, additional_properties: nil) ⇒ Previous

Returns a new instance of Previous.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/previous.rb', line 47

def initialize(href: SKIP, method: SKIP, body: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @href = href unless href == SKIP
  @method = method unless method == SKIP
  @body = body unless body == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bodyObject

Request body for this page

Returns:

  • (Object)


22
23
24
# File 'lib/usps_api/models/previous.rb', line 22

def body
  @body
end

#hrefString

Endpoint URL (always /reporter)

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/previous.rb', line 14

def href
  @href
end

#methodMethod1

HTTP method to use (POST)

Returns:



18
19
20
# File 'lib/usps_api/models/previous.rb', line 18

def method
  @method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/previous.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  href = hash.key?('href') ? hash['href'] : SKIP
  method = hash.key?('method') ? hash['method'] : SKIP
  body = hash.key?('body') ? hash['body'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Previous.new(href: href,
               method: method,
               body: body,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/previous.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['href'] = 'href'
  @_hash['method'] = 'method'
  @_hash['body'] = 'body'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/previous.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/previous.rb', line 34

def self.optionals
  %w[
    href
    method
    body
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/usps_api/models/previous.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} href: #{@href.inspect}, method: #{@method.inspect}, body: #{@body.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/usps_api/models/previous.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} href: #{@href}, method: #{@method}, body: #{@body}, additional_properties:"\
  " #{@additional_properties}>"
end