Class: UspsApi::QrCodeRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/qr_code_request.rb

Overview

Request for a new QR Code

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tracking_number:, zip_code:, additional_properties: nil) ⇒ QrCodeRequest

Returns a new instance of QrCodeRequest.



38
39
40
41
42
43
44
45
# File 'lib/usps_api/models/qr_code_request.rb', line 38

def initialize(tracking_number:, zip_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tracking_number = tracking_number
  @zip_code = zip_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#tracking_numberString

The package tracking number.

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/qr_code_request.rb', line 14

def tracking_number
  @tracking_number
end

#zip_codeString

The 11-digit delivery ZIP Code.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/qr_code_request.rb', line 18

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/usps_api/models/qr_code_request.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tracking_number =
    hash.key?('trackingNumber') ? hash['trackingNumber'] : nil
  zip_code = hash.key?('ZIPCode') ? hash['ZIPCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  QrCodeRequest.new(tracking_number: tracking_number,
                    zip_code: zip_code,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/qr_code_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tracking_number'] = 'trackingNumber'
  @_hash['zip_code'] = 'ZIPCode'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/usps_api/models/qr_code_request.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/usps_api/models/qr_code_request.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/usps_api/models/qr_code_request.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number.inspect}, zip_code:"\
  " #{@zip_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/usps_api/models/qr_code_request.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tracking_number: #{@tracking_number}, zip_code: #{@zip_code},"\
  " additional_properties: #{@additional_properties}>"
end