Class: UspsApi::ServiceStandardsDomesticAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/service_standards_domestic_address.rb

Overview

Address fields for US locations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(street_address: SKIP, street_address_abbreviation: SKIP, secondary_address: SKIP, city_abbreviation: SKIP, city: SKIP, state: SKIP, zip_code: SKIP, zip_plus4: SKIP, urbanization: SKIP) ⇒ ServiceStandardsDomesticAddress

Returns a new instance of ServiceStandardsDomesticAddress.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 85

def initialize(street_address: SKIP, street_address_abbreviation: SKIP,
               secondary_address: SKIP, city_abbreviation: SKIP, city: SKIP,
               state: SKIP, zip_code: SKIP, zip_plus4: SKIP,
               urbanization: SKIP)
  @street_address = street_address unless street_address == SKIP
  unless street_address_abbreviation == SKIP
    @street_address_abbreviation =
      street_address_abbreviation
  end
  @secondary_address = secondary_address unless secondary_address == SKIP
  @city_abbreviation = city_abbreviation unless city_abbreviation == SKIP
  @city = city unless city == SKIP
  @state = state unless state == SKIP
  @zip_code = zip_code unless zip_code == SKIP
  @zip_plus4 = zip_plus4 unless zip_plus4 == SKIP
  @urbanization = urbanization unless urbanization == SKIP
end

Instance Attribute Details

#cityString

City Name.

Returns:

  • (String)


31
32
33
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 31

def city
  @city
end

#city_abbreviationString

City Name Abbreviation.

Returns:

  • (String)


27
28
29
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 27

def city_abbreviation
  @city_abbreviation
end

#secondary_addressString

Suite or apartment number.

Returns:

  • (String)


23
24
25
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 23

def secondary_address
  @secondary_address
end

#stateString

2-letter USPS state abbreviation.

Returns:

  • (String)


35
36
37
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 35

def state
  @state
end

#street_addressString

The number of a building along with the name of the road or street on which it is located.

Returns:

  • (String)


15
16
17
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 15

def street_address
  @street_address
end

#street_address_abbreviationString

Primary address line abbreviations.

Returns:

  • (String)


19
20
21
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 19

def street_address_abbreviation
  @street_address_abbreviation
end

#urbanizationString

An area, sector, or residential development within a geographic area (typically used for addresses in Puerto Rico).

Returns:

  • (String)


48
49
50
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 48

def urbanization
  @urbanization
end

#zip_codeString

5-digit ZIP code.

Returns:

  • (String)


39
40
41
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 39

def zip_code
  @zip_code
end

#zip_plus4String

ZIP+4 extension.

Returns:

  • (String)


43
44
45
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 43

def zip_plus4
  @zip_plus4
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 104

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  street_address = hash.key?('streetAddress') ? hash['streetAddress'] : SKIP
  street_address_abbreviation =
    hash.key?('streetAddressAbbreviation') ? hash['streetAddressAbbreviation'] : SKIP
  secondary_address =
    hash.key?('secondaryAddress') ? hash['secondaryAddress'] : SKIP
  city_abbreviation =
    hash.key?('cityAbbreviation') ? hash['cityAbbreviation'] : SKIP
  city = hash.key?('city') ? hash['city'] : SKIP
  state = hash.key?('state') ? hash['state'] : SKIP
  zip_code = hash.key?('ZIPCode') ? hash['ZIPCode'] : SKIP
  zip_plus4 = hash.key?('ZIPPlus4') ? hash['ZIPPlus4'] : SKIP
  urbanization = hash.key?('urbanization') ? hash['urbanization'] : SKIP

  # Create object from extracted values.
  ServiceStandardsDomesticAddress.new(street_address: street_address,
                                      street_address_abbreviation: street_address_abbreviation,
                                      secondary_address: secondary_address,
                                      city_abbreviation: city_abbreviation,
                                      city: city,
                                      state: state,
                                      zip_code: zip_code,
                                      zip_plus4: zip_plus4,
                                      urbanization: urbanization)
end

.namesObject

A mapping from model property names to API property names.



51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 51

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['street_address'] = 'streetAddress'
  @_hash['street_address_abbreviation'] = 'streetAddressAbbreviation'
  @_hash['secondary_address'] = 'secondaryAddress'
  @_hash['city_abbreviation'] = 'cityAbbreviation'
  @_hash['city'] = 'city'
  @_hash['state'] = 'state'
  @_hash['zip_code'] = 'ZIPCode'
  @_hash['zip_plus4'] = 'ZIPPlus4'
  @_hash['urbanization'] = 'urbanization'
  @_hash
end

.nullablesObject

An array for nullable fields



81
82
83
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 81

def self.nullables
  []
end

.optionalsObject

An array for optional fields



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 66

def self.optionals
  %w[
    street_address
    street_address_abbreviation
    secondary_address
    city_abbreviation
    city
    state
    zip_code
    zip_plus4
    urbanization
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



143
144
145
146
147
148
149
150
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 143

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} street_address: #{@street_address.inspect}, street_address_abbreviation:"\
  " #{@street_address_abbreviation.inspect}, secondary_address: #{@secondary_address.inspect},"\
  " city_abbreviation: #{@city_abbreviation.inspect}, city: #{@city.inspect}, state:"\
  " #{@state.inspect}, zip_code: #{@zip_code.inspect}, zip_plus4: #{@zip_plus4.inspect},"\
  " urbanization: #{@urbanization.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



134
135
136
137
138
139
140
# File 'lib/usps_api/models/service_standards_domestic_address.rb', line 134

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} street_address: #{@street_address}, street_address_abbreviation:"\
  " #{@street_address_abbreviation}, secondary_address: #{@secondary_address},"\
  " city_abbreviation: #{@city_abbreviation}, city: #{@city}, state: #{@state}, zip_code:"\
  " #{@zip_code}, zip_plus4: #{@zip_plus4}, urbanization: #{@urbanization}>"
end