Class: UspsApi::TotalPostage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/total_postage.rb

Overview

The claimed and assessed total postage for the package.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(claimed: SKIP, assessed: SKIP, additional_properties: nil) ⇒ TotalPostage

Returns a new instance of TotalPostage.



41
42
43
44
45
46
47
48
# File 'lib/usps_api/models/total_postage.rb', line 41

def initialize(claimed: SKIP, assessed: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @claimed = claimed unless claimed == SKIP
  @assessed = assessed unless assessed == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#assessedFloat

The census value for the ingredient

Returns:

  • (Float)


18
19
20
# File 'lib/usps_api/models/total_postage.rb', line 18

def assessed
  @assessed
end

#claimedFloat

Manifest value of the ingredient

Returns:

  • (Float)


14
15
16
# File 'lib/usps_api/models/total_postage.rb', line 14

def claimed
  @claimed
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/usps_api/models/total_postage.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  claimed = hash.key?('claimed') ? hash['claimed'] : SKIP
  assessed = hash.key?('assessed') ? hash['assessed'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TotalPostage.new(claimed: claimed,
                   assessed: assessed,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/total_postage.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['claimed'] = 'claimed'
  @_hash['assessed'] = 'assessed'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/total_postage.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/total_postage.rb', line 29

def self.optionals
  %w[
    claimed
    assessed
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/usps_api/models/total_postage.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} claimed: #{@claimed.inspect}, assessed: #{@assessed.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/usps_api/models/total_postage.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} claimed: #{@claimed}, assessed: #{@assessed}, additional_properties:"\
  " #{@additional_properties}>"
end