Class: UspsApi::TruckManeuveringArea

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/truck_maneuvering_area.rb

Overview

Details on the maneuvering area at the facility.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(length: SKIP, width: SKIP, surface_type: SKIP, additional_properties: nil) ⇒ TruckManeuveringArea

Returns a new instance of TruckManeuveringArea.



47
48
49
50
51
52
53
54
55
56
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 47

def initialize(length: SKIP, width: SKIP, surface_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @length = length unless length == SKIP
  @width = width unless width == SKIP
  @surface_type = surface_type unless surface_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#lengthInteger

The length of the truck maneuvering area (in feet).

Returns:

  • (Integer)


14
15
16
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 14

def length
  @length
end

#surface_typeSurfaceType

The type of material used to create the truck maneuvering area.

Returns:



22
23
24
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 22

def surface_type
  @surface_type
end

#widthInteger

The width of the truck maneuvering area (in feet).

Returns:

  • (Integer)


18
19
20
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 18

def width
  @width
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  length = hash.key?('length') ? hash['length'] : SKIP
  width = hash.key?('width') ? hash['width'] : SKIP
  surface_type = hash.key?('surfaceType') ? hash['surfaceType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TruckManeuveringArea.new(length: length,
                           width: width,
                           surface_type: surface_type,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['length'] = 'length'
  @_hash['width'] = 'width'
  @_hash['surface_type'] = 'surfaceType'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 34

def self.optionals
  %w[
    length
    width
    surface_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} length: #{@length.inspect}, width: #{@width.inspect}, surface_type:"\
  " #{@surface_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/usps_api/models/truck_maneuvering_area.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} length: #{@length}, width: #{@width}, surface_type: #{@surface_type},"\
  " additional_properties: #{@additional_properties}>"
end