Class: UspsApi::Warning

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/usps_api/models/warning.rb

Overview

Warning Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(warning_code: SKIP, warning_description: SKIP) ⇒ Warning

Returns a new instance of Warning.



41
42
43
44
# File 'lib/usps_api/models/warning.rb', line 41

def initialize(warning_code: SKIP, warning_description: SKIP)
  @warning_code = warning_code unless warning_code == SKIP
  @warning_description = warning_description unless warning_description == SKIP
end

Instance Attribute Details

#warning_codeString

Code corresponding to the warning

Returns:

  • (String)


14
15
16
# File 'lib/usps_api/models/warning.rb', line 14

def warning_code
  @warning_code
end

#warning_descriptionString

Warning or additional information regarding the Extra Service.

Returns:

  • (String)


18
19
20
# File 'lib/usps_api/models/warning.rb', line 18

def warning_description
  @warning_description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/usps_api/models/warning.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  warning_code = hash.key?('warningCode') ? hash['warningCode'] : SKIP
  warning_description =
    hash.key?('warningDescription') ? hash['warningDescription'] : SKIP

  # Create object from extracted values.
  Warning.new(warning_code: warning_code,
              warning_description: warning_description)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/usps_api/models/warning.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['warning_code'] = 'warningCode'
  @_hash['warning_description'] = 'warningDescription'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/usps_api/models/warning.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/usps_api/models/warning.rb', line 29

def self.optionals
  %w[
    warning_code
    warning_description
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Warning | Hash)

    value against the validation is performed.



62
63
64
65
66
67
68
# File 'lib/usps_api/models/warning.rb', line 62

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/usps_api/models/warning.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} warning_code: #{@warning_code.inspect}, warning_description:"\
  " #{@warning_description.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/usps_api/models/warning.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} warning_code: #{@warning_code}, warning_description:"\
  " #{@warning_description}>"
end