Class: UspsApi::DutiesTaxesFeesQuote
- Defined in:
- lib/usps_api/models/duties_taxes_fees_quote.rb
Overview
The duties, taxes, and fees details. Included if ‘requestDutiesTaxesFees` is `true` and the shipping destination has applicable duties, taxes, and fees.
Instance Attribute Summary collapse
-
#item_quotes ⇒ Array[ItemQuote]
The total landed cost prices for taxes and duties on each item.
-
#package_fee ⇒ Float
The value of the total landed cost fee associated with the package.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(package_fee: SKIP, item_quotes: SKIP, additional_properties: nil) ⇒ DutiesTaxesFeesQuote
constructor
A new instance of DutiesTaxesFeesQuote.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_fee: SKIP, item_quotes: SKIP, additional_properties: nil) ⇒ DutiesTaxesFeesQuote
Returns a new instance of DutiesTaxesFeesQuote.
42 43 44 45 46 47 48 49 50 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 42 def initialize(package_fee: SKIP, item_quotes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @package_fee = package_fee unless package_fee == SKIP @item_quotes = item_quotes unless item_quotes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#item_quotes ⇒ Array[ItemQuote]
The total landed cost prices for taxes and duties on each item.
19 20 21 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 19 def item_quotes @item_quotes end |
#package_fee ⇒ Float
The value of the total landed cost fee associated with the package.
15 16 17 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 15 def package_fee @package_fee end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. package_fee = hash.key?('packageFee') ? hash['packageFee'] : SKIP # Parameter is an array, so we need to iterate through it item_quotes = nil unless hash['itemQuotes'].nil? item_quotes = [] hash['itemQuotes'].each do |structure| item_quotes << (ItemQuote.from_hash(structure) if structure) end end item_quotes = SKIP unless hash.key?('itemQuotes') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DutiesTaxesFeesQuote.new(package_fee: package_fee, item_quotes: item_quotes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['package_fee'] = 'packageFee' @_hash['item_quotes'] = 'itemQuotes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 30 def self.optionals %w[ package_fee item_quotes ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_fee: #{@package_fee.inspect}, item_quotes: #{@item_quotes.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/usps_api/models/duties_taxes_fees_quote.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_fee: #{@package_fee}, item_quotes: #{@item_quotes},"\ " additional_properties: #{@additional_properties}>" end |