Class: UspsApi::LabelsIndiciaRequest
- Defined in:
- lib/usps_api/models/labels_indicia_request.rb
Overview
Indicia request for letters, flats, and cards First-Class mailings.
Instance Attribute Summary collapse
-
#image_info ⇒ ImageInfo2
Additional details used to determine how to generate the indicia image.
-
#indicia_description ⇒ LabelsIndiciaRequestDescription
The ‘IndiciaRequestDescription` object defines the physical dimensions, mailing date, processing category, and weight required for processing a First-Class letter, flat, or card.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(indicia_description:, image_info: SKIP, additional_properties: nil) ⇒ LabelsIndiciaRequest
constructor
A new instance of LabelsIndiciaRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(indicia_description:, image_info: SKIP, additional_properties: nil) ⇒ LabelsIndiciaRequest
Returns a new instance of LabelsIndiciaRequest.
42 43 44 45 46 47 48 49 50 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 42 def initialize(indicia_description:, image_info: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @indicia_description = indicia_description @image_info = image_info unless image_info == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#image_info ⇒ ImageInfo2
Additional details used to determine how to generate the indicia image.
20 21 22 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 20 def image_info @image_info end |
#indicia_description ⇒ LabelsIndiciaRequestDescription
The ‘IndiciaRequestDescription` object defines the physical dimensions, mailing date, processing category, and weight required for processing a First-Class letter, flat, or card.
16 17 18 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 16 def indicia_description @indicia_description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. indicia_description = LabelsIndiciaRequestDescription.from_hash(hash['indiciaDescription']) if hash['indiciaDescription'] image_info = ImageInfo2.from_hash(hash['imageInfo']) if hash['imageInfo'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LabelsIndiciaRequest.new(indicia_description: indicia_description, image_info: image_info, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['indicia_description'] = 'indiciaDescription' @_hash['image_info'] = 'imageInfo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 31 def self.optionals %w[ image_info ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} indicia_description: #{@indicia_description.inspect}, image_info:"\ " #{@image_info.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/usps_api/models/labels_indicia_request.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} indicia_description: #{@indicia_description}, image_info: #{@image_info},"\ " additional_properties: #{@additional_properties}>" end |