Class: UspsApi::Sack
- Defined in:
- lib/usps_api/models/sack.rb
Overview
Sack Model.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Count for sacks.
-
#impb ⇒ String
Intelligent Mail Package Barcode.
-
#pre_sort_level ⇒ Array[PreSortLevel]
Array for the preSortLevel objects.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(pre_sort_level: SKIP, impb: SKIP, count: SKIP, additional_properties: nil) ⇒ Sack
constructor
A new instance of Sack.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(pre_sort_level: SKIP, impb: SKIP, count: SKIP, additional_properties: nil) ⇒ Sack
Returns a new instance of Sack.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/usps_api/models/sack.rb', line 48 def initialize(pre_sort_level: SKIP, impb: SKIP, count: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @pre_sort_level = pre_sort_level unless pre_sort_level == SKIP @impb = impb unless impb == SKIP @count = count unless count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
Count for sacks. Required for Create actions. (One of pallets, sacks, trays count)
23 24 25 |
# File 'lib/usps_api/models/sack.rb', line 23 def count @count end |
#impb ⇒ String
Intelligent Mail Package Barcode
18 19 20 |
# File 'lib/usps_api/models/sack.rb', line 18 def impb @impb end |
#pre_sort_level ⇒ Array[PreSortLevel]
Array for the preSortLevel objects
14 15 16 |
# File 'lib/usps_api/models/sack.rb', line 14 def pre_sort_level @pre_sort_level end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/usps_api/models/sack.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it pre_sort_level = nil unless hash['preSortLevel'].nil? pre_sort_level = [] hash['preSortLevel'].each do |structure| pre_sort_level << (PreSortLevel.from_hash(structure) if structure) end end pre_sort_level = SKIP unless hash.key?('preSortLevel') impb = hash.key?('IMPB') ? hash['IMPB'] : SKIP count = hash.key?('count') ? hash['count'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Sack.new(pre_sort_level: pre_sort_level, impb: impb, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/usps_api/models/sack.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['pre_sort_level'] = 'preSortLevel' @_hash['impb'] = 'IMPB' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/usps_api/models/sack.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/usps_api/models/sack.rb', line 35 def self.optionals %w[ pre_sort_level impb count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/usps_api/models/sack.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} pre_sort_level: #{@pre_sort_level.inspect}, impb: #{@impb.inspect}, count:"\ " #{@count.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/usps_api/models/sack.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} pre_sort_level: #{@pre_sort_level}, impb: #{@impb}, count: #{@count},"\ " additional_properties: #{@additional_properties}>" end |